;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "focus" "20241029.1506"
  "Dim the font color of text in surrounding sections."
  '((emacs  "24.3")
    (cl-lib "0.5"))
  :url "http://github.com/larstvei/Focus"
  :commit "29b412b209c3542a7932c201f0166e48c9fd7fee"
  :revdesc "29b412b209c3"
  :authors '(("Lars Tveito" . "larstvei@ifi.uio.no"))
  :maintainers '(("Lars Tveito" . "larstvei@ifi.uio.no")))
